@@ -61,8 +61,8 @@ class ModelConverter:
     def _find_tensor_index_by_name(self, node_input_tensors: List[KerasTensor], tensor_name: str) -> int:
         node_input_tensor_names = []
         for tensor in node_input_tensors:
-            if tensor.name in self._permuted_tensor_name_to_original_tensor_name:
-                node_input_tensor_names.append(self._permuted_tensor_name_to_original_tensor_name[tensor.name])
+            if tensor.name in self._tensor_name_to_original_tensor_name:
+                node_input_tensor_names.append(self._tensor_name_to_original_tensor_name[tensor.name])
             else:
                 node_input_tensor_names.append(tensor.name)
 
@@ -168,7 +168,7 @@ class ModelConverter:
             converted_layer.set_weights(weights)
             perm_values = calculate_permute_values(tensor.shape, to_channel_first=True)
             permute_after = tf.keras.layers.Permute(perm_values)(tensor)
-            self._permuted_tensor_name_to_original_tensor_name[permute_after.name] = tensor.name
+            self._tensor_name_to_original_tensor_name[permute_after.name] = tensor.name
             converted_tensor = permute_after
         else:
             weights = current_layer.get_weights()
@@ -196,7 +196,10 @@ class ModelConverter:
     def _convert_input_tensor(self, input_tensor: tf.Tensor) -> tf.Tensor:
         input_layer = input_tensor._keras_history.layer
         inp_config = input_layer.get_config()
-
+        if 'name' in inp_config and '.' in inp_config['name']:
+            new_name_without_dots = inp_config['name'].replace(".", "_")
+            self._tensor_name_to_original_tensor_name[new_name_without_dots] = inp_config['name']
+            inp_config['name'] = new_name_without_dots
         new_input_tensor = Input(**inp_config)
         self._logger.debug(f"Input created, name: {new_input_tensor.name}, shape: {new_input_tensor.shape}")
         return new_input_tensor
@@ -205,5 +208,5 @@ class ModelConverter:
         self._layer_cache: Dict[str, Layer] = {}
         self._tensor_cache: Dict[int, tf.Tensor] = {}
         self._model_input_tensors: List[tf.Tensor] = []
-        self._permuted_tensor_name_to_original_tensor_name: Dict[str, str] = {}
+        self._tensor_name_to_original_tensor_name: Dict[str, str] = {}
 
